@@ -1,10 +1,10 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9404';
+$XML::MyXML::VERSION = '0.9405';
 use strict;
 use warnings;
 use Carp;
-use Scalar::Util qw( weaken );
+use Scalar::Util qw/ weaken /;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(tidy_xml object_to_xml xml_to_object simple_to_xml xml_to_simple check_xml xml_escape);
@@ -228,7 +228,7 @@ sub _objectarray_to_xml {
 			foreach my $attrname (keys %{$stuff->{attrs}}) {
 				$xml .= " ".$attrname.'="'._encode($stuff->{attrs}{$attrname}).'"';
 			}
-			if (! defined $stuff->{content}) {
+			if (! defined $stuff->{content} or ! @{ $stuff->{content} }) {
 				$xml .= "/>"
 			} else {
 				$xml .= ">";
@@ -473,9 +473,10 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9404';
+$XML::MyXML::Object::VERSION = '0.9405';
 use Carp;
 use Encode;
+use Scalar::Util qw/ weaken /;
 
 
 sub new {
@@ -567,17 +568,36 @@ sub path {
 
 sub value {
 	my $self = shift;
-	my $flags = shift || {};
+	my $flags = (@_ and ref $_[-1]) ? pop : {};
+	my $set_value = @_ ? (shift // '') : undef;
 
-	if ($self->{content} and $self->{content}[0]) {
-		my $value = $self->{content}[0]{value};
-		if ($flags->{strip}) { $value = XML::MyXML::_strip($value); }
+	if (! defined $set_value) {
+		my $value = '';
+		if ($self->{content}) {
+			foreach my $child (@{ $self->{content} }) {
+				$value .= $child->value($flags);
+			}
+		}
+		if ($self->{value}) {
+			my $temp_value = $self->{value};
+			if ($flags->{strip}) { $temp_value = XML::MyXML::_strip($temp_value); }
+			$value .= $temp_value;
+		}
 		return $value;
 	} else {
-		return undef;
+		if (length $set_value) {
+			my $entry = { value => $set_value, parent => $self };
+			weaken( $entry->{parent} );
+			bless $entry, 'XML::MyXML::Object';
+			$self->{content} = [ $entry ];
+		} else {
+			$self->{content} = [];
+		}
 	}
 }
 
+*text = \&value;
+
 
 sub attr {
 	my $self = shift;
@@ -697,7 +717,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9404
+version 0.9405
 
 =head1 SYNOPSIS
 
@@ -708,7 +728,7 @@ version 0.9404
     print tidy_xml($xml);
 
     my $obj = xml_to_object($xml);
-    print "Price in Euros = " . $obj->path('price/eur')->value;
+    print "Price in Euros = " . $obj->path('price/eur')->text;
 
     $obj->simplify is hashref { item => { name => 'Table', price => { usd => '10.00', eur => '8.50' } } }
     $obj->simplify({ internal => 1 }) is hashref { name => 'Table', price => { usd => '10.00', eur => '8.50' } }
@@ -863,9 +883,9 @@ If you wish to describe the root element in the path as well, prepend it in the
 
 Optional flags: none
 
-=head2 $obj->value
+=head2 $obj->text([set_value]), also known as $obj->value([set_value])
 
-When the element represented by the $obj object has only text contents, returns those contents as a string. If the $obj element has no contents, value will return an empty string.
+If provided a set_value, will delete all contents of $obj and will place C<set_value> as its text contents. Otherwise will return the text contents of this object, and of its descendants, in a single string.
 
 Optional flags: C<strip>
 
